package exampleSetWidgets;
import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.border.*;

/**
 * Frame that demonstrates the five basic types of buttons: push buttons,
 * checkboxes, radio buttons, modal buttons and combo box.
 * <p>
 * For simplicity, the buttons do not have mnemonics enabled.
 * <p>
 * 
 * @see <a href="../DemoButtons.java">source code</a>
 * @author Scott MacKenzie, 2002; extensively modified MB, 2007
 */
public class DemoButtonsFrameFiveTypes extends JFrame {
	private JTextField message;
	private JButton exitButton;
	private JButton restoreButton;
	private JCheckBox italicCheckBox;
	private JCheckBox boldCheckBox;
	private JRadioButton smallButton;
	private JRadioButton mediumButton;
	private JRadioButton largeButton;
	private JToggleButton toggleFontSizeButton;
	private JComboBox sizeCombo;

	private final Color FOREGROUND = Color.blue;
	private final Color BACKGROUND = Color.pink;
	private final int SMALL = 12;
	private final int MEDIUM = 24;
	private final int LARGE = 48;
	private final String DEFAULT_TYPE = "Serif";
	private final int DEFAULT_STYLE = Font.PLAIN;
	private final int DEFAULT_SIZE = MEDIUM;
	private final boolean DEFAULT_BOOLEAN = false;
	// final int DEFAULT_SIZE_INDEX = 3;
	final String[] SZ = { "12", "16", "20", "24", "28", "32", "36", "48" };

	private boolean isBoldOn = DEFAULT_BOOLEAN;
	private boolean isItalicsOn = DEFAULT_BOOLEAN;
	private int fontSize = DEFAULT_SIZE;

	public DemoButtonsFrameFiveTypes() {
		// ----------------------------------
		// construct and configure components
		// ----------------------------------

		message = new JTextField("Hello Java World");
		message.setFont(new Font(DEFAULT_TYPE, DEFAULT_STYLE, DEFAULT_SIZE));
		message.setEditable(false);
		message.setBackground(BACKGROUND);
		message.setForeground(FOREGROUND);
		message.setHorizontalAlignment(SwingConstants.CENTER);
		message.setPreferredSize(new Dimension(400, 150));

		restoreButton = new JButton("Default");
		exitButton = new JButton("Exit");
		restoreButton.setMnemonic(KeyEvent.VK_R);
		exitButton.setMnemonic(KeyEvent.VK_E);

		italicCheckBox = new JCheckBox("Italic");
		boldCheckBox = new JCheckBox("Bold");
		italicCheckBox.setMnemonic(KeyEvent.VK_I);
		boldCheckBox.setMnemonic(KeyEvent.VK_B);

		smallButton = new JRadioButton("Small");
		mediumButton = new JRadioButton("Medium");
		largeButton = new JRadioButton("Large");
		smallButton.setMnemonic(KeyEvent.VK_S);
		mediumButton.setMnemonic(KeyEvent.VK_M);
		largeButton.setMnemonic(KeyEvent.VK_L);

		mediumButton.setSelected(true);
		ButtonGroup sizeGroup = new ButtonGroup();
		sizeGroup.add(smallButton);
		sizeGroup.add(mediumButton);
		sizeGroup.add(largeButton);

		toggleFontSizeButton = new JToggleButton("Font Size:" + SMALL);

		sizeCombo = new JComboBox(SZ);
		// center align the entries
		((JLabel) sizeCombo.getRenderer())
				.setHorizontalAlignment(SwingConstants.CENTER);
		sizeCombo.setSelectedItem("" + DEFAULT_SIZE);
		sizeCombo.setPreferredSize(new Dimension(50, 1));

		// -------------
		// add listeners
		// -------------
		restoreButton.addActionListener(new DefaultButtonActionListener());
		exitButton.addActionListener(new ExitButtonActionListener());

		italicCheckBox.addItemListener(new ItalItemListener());
		boldCheckBox.addItemListener(new BoldItemListener());

		smallButton.addActionListener(new SmallFontButtonActionListener());
		mediumButton.addActionListener(new MedFontButtonActionListener());
		largeButton.addActionListener(new LargeFontButtonActionListener());
		toggleFontSizeButton
				.addActionListener(new ToggleFontSizeButtonActionListener());
		sizeCombo.addActionListener(new SizeComboActionListener());

		// -----------------
		// layout components
		// -----------------

		// add components to panels

		JPanel commandPanel = new JPanel();
		commandPanel.setLayout(new GridLayout(2, 1));
		commandPanel.add(restoreButton);
		commandPanel.add(exitButton);
		commandPanel
				.setBorder(new TitledBorder(new EtchedBorder(), "Commands"));

		JPanel sizeGroupPanel = new JPanel();
		sizeGroupPanel.setLayout(new GridLayout(3, 1));
		sizeGroupPanel.add(smallButton);
		sizeGroupPanel.add(mediumButton);
		sizeGroupPanel.add(largeButton);
		sizeGroupPanel.setBorder(new TitledBorder(new EtchedBorder(), "Size"));

		JPanel styleGroupPanel = new JPanel();
		styleGroupPanel.setLayout(new GridLayout(2, 1));
		styleGroupPanel.add(italicCheckBox);
		styleGroupPanel.add(boldCheckBox);
		styleGroupPanel
				.setBorder(new TitledBorder(new EtchedBorder(), "Style"));

		JPanel toggleButtonPanel = new JPanel();
		toggleButtonPanel.setLayout(new GridLayout(2, 1));
		toggleButtonPanel.add(toggleFontSizeButton);
		toggleButtonPanel.setBorder(new TitledBorder(new EtchedBorder(),
				"Change to:"));

		Dimension d = commandPanel.getPreferredSize();

		JPanel sizePanel = new JPanel();
		sizePanel.setLayout(new GridLayout(2, 1));
		sizePanel.add(sizeCombo);
		sizePanel.setBorder(new TitledBorder(new EtchedBorder(), "Size"));
		sizePanel.setPreferredSize(d);

		// arrange panels

		JPanel southPanel = new JPanel();
		southPanel.setLayout(new GridLayout(1, 4));
		southPanel.add(commandPanel);
		southPanel.add(styleGroupPanel);
		southPanel.add(sizeGroupPanel);
		southPanel.add(toggleButtonPanel);
		southPanel.add(sizePanel);

		JPanel contentPane = new JPanel();
		contentPane.setLayout(new BorderLayout());
		contentPane.add(message, "Center");
		contentPane.add(southPanel, "South");
		contentPane.setBorder(BorderFactory.createEmptyBorder(30, 30, 30, 30));

		// make panel this JFrame's content pane

		this.setContentPane(contentPane);
	}

	public boolean isItalicsOn() {
		return isItalicsOn;
	}

	public void setItalicsOn(boolean isItalicsOn) {
		this.isItalicsOn = isItalicsOn;
	}

	public boolean isBoldOn() {
		return isBoldOn;
	}

	public void setBoldOn(boolean isBoldOn) {
		this.isBoldOn = isBoldOn;
	}

	public int getFontSize() {
		return fontSize;
	}

	public void setFontSize(int fontSize) {
		this.fontSize = fontSize;
	}

	private void updateDisplay() {
		int fontStyle = message.getFont().getStyle();
		if (isBoldOn())
			fontStyle = fontStyle | Font.BOLD; // turn bold on, using
		// bitwise "OR"
		else
			fontStyle = fontStyle & ~Font.BOLD; // turn bold off, using

		if (isItalicsOn())
			fontStyle = fontStyle | Font.ITALIC; // turn italic on
		else
			fontStyle = fontStyle & ~Font.ITALIC; // turn italic off

		message.setFont(new Font(DEFAULT_TYPE, fontStyle, getFontSize()));
		sizeCombo.setSelectedItem("" + getFontSize());
	}

	private void setDefaultDisplay() {
		if (italicCheckBox.isSelected()) {
			italicCheckBox.doClick();
		}
		if (boldCheckBox.isSelected()) {
			boldCheckBox.doClick();
		}
		mediumButton.doClick();
		toggleFontSizeButton.setText("Font Size:" + LARGE);
		sizeCombo.setSelectedItem("" + DEFAULT_SIZE);
	}

	class DefaultButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			setDefaultDisplay();
		}
	}

	class ExitButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			System.exit(0);
		}
	}

	class SmallFontButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			setFontSize(SMALL);
			updateDisplay();
		}
	}

	class MedFontButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			setFontSize(MEDIUM);
			updateDisplay();
		}
	}

	class LargeFontButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			setFontSize(LARGE);
			updateDisplay();
		}
	}

	class ToggleFontSizeButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			if (ae.getActionCommand().equals("Font Size:" + SMALL)) {
				smallButton.doClick();
				toggleFontSizeButton.setText("Font Size:" + MEDIUM);
			} else if (ae.getActionCommand().equals("Font Size:" + MEDIUM)) {
				mediumButton.doClick();
				toggleFontSizeButton.setText("Font Size:" + LARGE);
			} else if (ae.getActionCommand().equals("Font Size:" + LARGE)) {
				largeButton.doClick();
				toggleFontSizeButton.setText("Font Size:" + SMALL);
			}
		}
	}

	class SizeComboActionListener implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			fontSize = Integer.parseInt((String) sizeCombo.getSelectedItem());
			setFontSize(fontSize);
			updateDisplay();
		}
	}

	class ItalItemListener implements ItemListener {
		public void itemStateChanged(ItemEvent ie) {
			if (italicCheckBox.isSelected())
				setItalicsOn(true);
			else
				setItalicsOn(false);
			updateDisplay();
		}
	}

	class BoldItemListener implements ItemListener {
		public void itemStateChanged(ItemEvent ie) {
			if (boldCheckBox.isSelected())
				setBoldOn(true);
			else
				setBoldOn(false);
			updateDisplay();
		}
	}

}
