package exampleSetWidgets;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

/**
 * Frame that demonstrates the two basic types of buttons: push buttons and
 * checkboxes.
 * <p>
 * For simplicity, the buttons do not have mnemonics enabled.
 * <p>
 * 
 * @see <a href="../DemoButtons.java">source code</a>
 * @author Scott MacKenzie, 2002; extensively modified MB, 2007
 */

public class DemoButtonsFrameTwoTypes extends JFrame {
	private JTextField message;
	private JButton exitButton;
	private JButton restoreButton;
	private JCheckBox italicCheckBox;
	private JCheckBox boldCheckBox;

	private final Color FOREGROUND = Color.blue;
	private final Color BACKGROUND = Color.pink;
	private final int MEDIUM = 24;
	private final String DEFAULT_TYPE = "Serif";
	private final int DEFAULT_STYLE = Font.PLAIN;
	private final int DEFAULT_SIZE = MEDIUM;
	private final boolean DEFAULT_BOOLEAN = false;

	private boolean isBoldOn = DEFAULT_BOOLEAN;
	private boolean isItalicsOn = DEFAULT_BOOLEAN;

	public DemoButtonsFrameTwoTypes() {
		// ----------------------------------
		// construct and configure components
		// ----------------------------------

		message = new JTextField("Hello Java World");
		message.setFont(new Font(DEFAULT_TYPE, DEFAULT_STYLE, DEFAULT_SIZE));
		message.setEditable(false);
		message.setBackground(BACKGROUND);
		message.setForeground(FOREGROUND);
		message.setHorizontalAlignment(SwingConstants.CENTER);
		message.setPreferredSize(new Dimension(400, 150));

		restoreButton = new JButton("Default");
		exitButton = new JButton("Exit");

		italicCheckBox = new JCheckBox("Italic");
		boldCheckBox = new JCheckBox("Bold");

		restoreButton.addActionListener(new DefaultButtonActionListener());
		exitButton.addActionListener(new ExitButtonActionListener());
		italicCheckBox.addItemListener(new ItalItemListener());
		boldCheckBox.addItemListener(new BoldItemListener());

		// -----------------
		// layout components
		// -----------------
		// add components to panels
		JPanel commandPanel = new JPanel();
		commandPanel.setLayout(new GridLayout(2, 1));
		commandPanel.add(restoreButton);
		commandPanel.add(exitButton);
		commandPanel
				.setBorder(new TitledBorder(new EtchedBorder(), "Commands"));

		JPanel styleGroupPanel = new JPanel();
		styleGroupPanel.setLayout(new GridLayout(2, 1));
		styleGroupPanel.add(italicCheckBox);
		styleGroupPanel.add(boldCheckBox);
		styleGroupPanel
				.setBorder(new TitledBorder(new EtchedBorder(), "Style"));

		// arrange panels
		JPanel southPanel = new JPanel();
		southPanel.setLayout(new GridLayout(1, 4));
		southPanel.add(commandPanel);
		southPanel.add(styleGroupPanel);

		JPanel contentPane = new JPanel();
		contentPane.setLayout(new BorderLayout());
		contentPane.add(message, "Center");
		contentPane.add(southPanel, "South");
		contentPane.setBorder(BorderFactory.createEmptyBorder(30, 30, 30, 30));

		// make panel this JFrame's content pane

		this.setContentPane(contentPane);
	}

	public boolean isItalicsOn() {
		return isItalicsOn;
	}

	public void setItalicsOn(boolean isItalicsOn) {
		this.isItalicsOn = isItalicsOn;
	}

	public boolean isBoldOn() {
		return isBoldOn;
	}

	public void setBoldOn(boolean isBoldOn) {
		this.isBoldOn = isBoldOn;
	}

	private void setDefaultDisplay() {
		if (italicCheckBox.isSelected()) {
			italicCheckBox.doClick();
		}
		if (boldCheckBox.isSelected()) {
			boldCheckBox.doClick();
		}

		// ANOTHER (NOT SO GOOD) WAY TO DO THIS:
		// fontSize = MEDIUM;
		// fontStyle = Font.PLAIN;
		// italicCheckBox.setSelected(false);
		// boldCheckBox.setSelected(false);
		// message.setFont(new Font("Serif", Font.PLAIN, MEDIUM));
	}

	private void updateDisplay() {
		int fontStyle = message.getFont().getStyle();
		if (isBoldOn())
			fontStyle = fontStyle | Font.BOLD; // turn bold on, using
		// bitwise "OR"
		else
			fontStyle = fontStyle & ~Font.BOLD; // turn bold off, using

		if (isItalicsOn())
			fontStyle = fontStyle | Font.ITALIC; // turn italic on
		else
			fontStyle = fontStyle & ~Font.ITALIC; // turn italic off
		message.setFont(new Font(DEFAULT_TYPE, fontStyle, DEFAULT_SIZE));
	}

	class DefaultButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			setDefaultDisplay();
		}
	}

	class ExitButtonActionListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			System.exit(0);
		}
	}

	class ItalItemListener implements ItemListener {
		public void itemStateChanged(ItemEvent ie) {
			if (italicCheckBox.isSelected())
				setItalicsOn(true);
			else
				setItalicsOn(false);
			updateDisplay();
		}
	}

	class BoldItemListener implements ItemListener {
		public void itemStateChanged(ItemEvent ie) {
			if (boldCheckBox.isSelected())
				setBoldOn(true);
			else
				setBoldOn(false);
			updateDisplay();
		}
	}

}
