package exampleSetWidgets;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * This application derives all of the 'look and feels' available on the system
 * in which it is invoked. The different look and feels are presented as
 * options, which can be selected using radiobuttons. When a radio button is
 * selected, the corresponding look and feel is applied to the application.
 * 
 * <b>Source code notes:</b><br>
 * 
 * This application uses the following statements to determine which LookAndFeel
 * options are available on the system:
 * <p>
 * 
 * <pre>
 * UIManager.LookAndFeelInfo[] laf;
 * laf = UIManager.getInstalledLookAndFeels();
 * </pre>
 * 
 * The method <code>getInstalledLookAndFeels</code> is a static method in the
 * <code>UIManager</code> class in the <code>javax.swing</code> package. It
 * returns an array of <code>UIManager.LookAndFeelInfo</code> objects. Each
 * object contains information about a LookAndFeel implementation available with
 * the installed software development kit.
 * <p>
 * 
 * The modification of the look and feel is accomplished by the following line
 * of code
 * <p>
 * 
 * <pre>
 * UIManager.setLookAndFeel(laf[i].getClassName());
 * </pre>
 * 
 * which is followed by
 * <p>
 * 
 * <pre>
 * SwingUtilities.updateComponentTreeUI(this);
 * this.pack();
 * </pre>
 * 
 * to force an update of the applications's component tree. See the source code
 * for further details.
 * <p>
 * 
 * @see <a href="../DemoLandF.java">source code</a>
 * @author M.Baljko, 2004 (based on the application <code>DemoLookAndFeel</code>
 *         by Scott MacKenzie, 2002)
 */
public class DemoLandF {
	public static void main(String[] args) {
		DemoLandFFrame frame = new DemoLandFFrame();
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setTitle("DemoLandF");
		frame.pack();
		frame.show();
	}
}

class DemoLandFFrame extends JFrame implements ActionListener {
	// declare private components
	private JPanel lafOptionPanel;
	private JRadioButton[] lafOption;
	UIManager.LookAndFeelInfo[] laf;
	private JTextField currLaFField;
	private JTextField defaultLaFField;
	private final int WIDTH = 400;
	private final int LABEL_WIDTH = 150;
	private final int HEIGHT = 30;

	public DemoLandFFrame() {
		// Construct and configure components
		// 1. A radiobutton for each Look and Feel defined on this system.
		System.out
				.println("LookAndFeel implementations installed on this system...");
		laf = UIManager.getInstalledLookAndFeels();
		for (int i = 0; i < laf.length; ++i) {
			System.out.println("-----");
			System.out.println("Name:  " + laf[i].getName());
			System.out.println("Class Name: " + laf[i].getClassName());
		}
		System.out.println("-----");

		laf = UIManager.getInstalledLookAndFeels();

		lafOptionPanel = new JPanel();
		lafOption = new JRadioButton[laf.length];
		ButtonGroup buttonGroup = new ButtonGroup();
		for (int i = 0; i < laf.length; ++i) {
			lafOption[i] = new JRadioButton(laf[i].getName());
			lafOption[i].addActionListener(this);
			lafOption[i].setActionCommand(laf[i].getName());
			lafOptionPanel.add(lafOption[i]);
			buttonGroup.add(lafOption[i]);
		}

		// 2. A text field to provide feedback about the current statusField
		// LookAndFeel
		JLabel currLaFLabel = new JLabel("Current look and feel: ",
				JLabel.RIGHT);
		JLabel defaultLaFLabel = new JLabel("Default look and feel: ",
				JLabel.RIGHT);
		currLaFLabel.setPreferredSize(new Dimension(LABEL_WIDTH, HEIGHT));
		defaultLaFLabel.setPreferredSize(new Dimension(LABEL_WIDTH, HEIGHT));

		currLaFField = new JTextField();
		currLaFField.setEditable(false);
		currLaFField.setPreferredSize(new Dimension(WIDTH, HEIGHT));

		defaultLaFField = new JTextField();
		defaultLaFField.setEditable(false);
		defaultLaFField.setPreferredSize(new Dimension(WIDTH, HEIGHT));

		// get this system's default look and feel
		String s = UIManager.getSystemLookAndFeelClassName();
		System.out.println("Class name of default look and feel: " + s);
		String s2 = UIManager.getCrossPlatformLookAndFeelClassName();
		System.out.println("Class name of cross-platform look and feel: " + s2);
		defaultLaFField.setText(s);
		try {
			for (int i = 0; i < laf.length; i++) {
				if ((laf[i].getClassName()).equals(s)) {
					UIManager.setLookAndFeel(s);
					lafOption[i].setSelected(true);
					currLaFField.setText(s);
					break;
				}
			}
		} catch (Exception e) {
			System.out.println("Exception: " + e);
			System.out.println(e);
			System.exit(0);
		}
		// add components to panel
		JPanel panel1 = new JPanel(new BorderLayout());
		panel1.add(defaultLaFLabel, "West");
		panel1.add(defaultLaFField, "East");

		JPanel panel2 = new JPanel(new BorderLayout());
		panel2.add(currLaFLabel, "West");
		panel2.add(currLaFField, "East");

		JPanel panel = new JPanel(new BorderLayout());
		panel.add(panel1, "North");
		panel.add(panel2, "Center");
		panel.add(lafOptionPanel, "South");
		// make panel this JFrame's content pane
		this.setContentPane(panel);
	}

	// -------------------------------
	// implement ActionListener method
	// -------------------------------

	public void actionPerformed(ActionEvent ae) {
		// see if a new look and feel was specified
		System.out.println("Look and Feel Selected: " + ae.getActionCommand());
		// We know the action command, but we need to derive the index
		// of the radio button that corresponds to that action. We
		// need the index so we can find the corresponding element in
		// laf, in order to get the fully-qualified name of the class.
		// lafOption is an array of simplified class names
		for (int i = 0; i < lafOption.length; ++i) {
			System.out.println("Checking element # " + i + " "
					+ laf[i].getClassName());
			if (ae.getActionCommand().equals(lafOption[i].getText())) {
				System.out.println("Match");
				try {
					// System.out.println( "Attempting to apply the following
					// look and feel: " + laf[i].getClassName() );
					UIManager.setLookAndFeel(laf[i].getClassName());
				} catch (Exception e) {
					System.out.println("Exception: " + e);
					System.out.println(e);
					System.exit(0);
				}
				currLaFField.setText(laf[i].getClassName());
				SwingUtilities.updateComponentTreeUI(this);
				this.pack();
				break;
			}
		}
	}
}
